import java.io.InputStream;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.FormulaEvaluator;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.junit.Assert;
import org.junit.Test;

public class DateArithmeticOnTextfieldTest
{

	@Test
	public void testDateArithmetic() throws Exception
	{
		InputStream is = this.getClass().getResourceAsStream("date_arithmetic_test.xls");
		Workbook wb = new HSSFWorkbook(is);

		Sheet sheet = wb.getSheetAt(0); // first sheet
		Row row = sheet.getRow(1); // second row
		Cell cell = row.getCell(1); // second cell

		if(cell.getCellType() == Cell.CELL_TYPE_FORMULA)
		{
			final FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
			// --> cell is evaluated to #VALUE!, Date expected
			cell = (HSSFCell) evaluator.evaluateInCell(cell);
		}

		SimpleDateFormat formatter = new SimpleDateFormat("dd.MM.yyyy");
		Date cellValueAsDate = getCellValueAsDate(cell, formatter);

		Assert.assertEquals(formatDate(formatter.parse("31.12.2011"), formatter), 
				formatDate(cellValueAsDate, formatter));
	}
	
	private static String formatDate(Date date, DateFormat formatter)
	{
		String ret = null;
		try
		{
			ret = formatter.format(date);
		}
		catch(Exception e)
		{
		}
		return ret;
	}

	private static Date getCellValueAsDate(Cell cell, DateFormat formatter)
	{
		Date ret = null;
		try
		{
			ret = formatter.parse(cell.toString());
		}
		catch(Exception e)
		{
		}
		return ret;
	}
}
